isAudio property
bool
get
isAudio
Returns whether this media type is of an audio clip.
Implementation
bool get isAudio => type == 'audio' || matchesAny([ogg, oga]);
Returns whether this media type is of an audio clip.
bool get isAudio => type == 'audio' || matchesAny([ogg, oga]);