OdlLoan class

An active loan record embedded in an ODL 1.0 License Info Document.

https://drafts.opds.io/odl-1.0.html

Implemented types
Annotations

Constructors

OdlLoan({required String href, required String id, required String patronId, required DateTime expires})
const

Properties

expires DateTime
When this loan expires.
final
hashCode int
The hash code for this object.
no setterinherited
href String
URL of the loan.
final
id String
Unique identifier of the loan.
final
patronId String
Identifier of the patron who holds the loan (JSON key: patron_id).
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the object to its JSON representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic>? json) OdlLoan?
fromJsonArray(dynamic json) List<OdlLoan>