PDFSpread enum

Synthetic spread (dual-page view) mode for PDF publications.

Maps to ReadiumNavigator.Spread on iOS. iOS only — Android PdfiumPreferences does not expose spread.

Inheritance
Available extensions

Values

auto → const PDFSpread

Show a spread when the screen is wide enough (portrait = single, landscape = two-up).

never → const PDFSpread

Never show two pages side by side.

always → const PDFSpread

Always show two pages side by side.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String? value) PDFSpread?

Constants

values → const List<PDFSpread>
A constant List of the values in this enum, in order of their declaration.