ProfileHolds class

Implemented types
Annotations

Constructors

ProfileHolds({double? total, double? available})
const
ProfileHolds.fromJson(Map<String, dynamic> json)
factory

Properties

available double?
Number of holds currently available to the user.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total double?
Number of holds allowed at any time for the users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the object to its JSON representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited