ReadingProgression enum
Direction of the Publication reading progression.
Values
- ltr → const ReadingProgression
-
Left-to-right reading progression.
- rtl → const ReadingProgression
-
Right-to-left reading progression.
- ttb → const ReadingProgression
-
Top to bottom reading progression.
- btt → const ReadingProgression
-
Bottom to top reading progression.
- auto → const ReadingProgression
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- leadingPage → PresentationPage
-
Returns the leading Page for the ReadingProgression.
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isHorizontal(
) → bool? - Indicates whether this reading progression is on the horizontal axis, or null if unknown.
-
isReverseOrder(
) → bool - Indicates whether items in this reading progression must be placed in natural or reverse order in the webviews
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ReadingProgression> - A constant List of the values in this enum, in order of their declaration.