SelectionActionEvent class

Fired when the user taps a configured editing action on selected text.

Implemented types

Constructors

SelectionActionEvent({required String actionId, required Locator locator, String? selectedText})
const
SelectionActionEvent.fromJson(Map<String, dynamic> map)
factory

Properties

actionId String
The ID of the action that was tapped (matches SelectionAction.id).
final
hashCode int
The hash code for this object.
no setterinherited
locator Locator
Location of the selection in the publication.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedText String?
The selected text content, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the object to its JSON representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited