TextSelectionEvent class

Fired when the user selects text in the reader.

Implemented types

Constructors

TextSelectionEvent({required Locator locator, String? selectedText})
const
TextSelectionEvent.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
locator Locator
Location of the selection in the publication.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedText String?
The selected text content, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the object to its JSON representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited