onDecorationInteraction property
Called when the user interacts with an existing decoration.
Implementation
void Function(DecorationInteractionEvent)? onDecorationInteraction;
Called when the user interacts with an existing decoration.
void Function(DecorationInteractionEvent)? onDecorationInteraction;