onExternalLinkActivated property
Called when the reader activates a link that points outside the publication.
Implementation
void Function(String)? onExternalLinkActivated;
Called when the reader activates a link that points outside the publication.
void Function(String)? onExternalLinkActivated;