onSelectionAction property
Called when the user taps a configured editing action on selected text.
Implementation
void Function(SelectionActionEvent)? onSelectionAction;
Called when the user taps a configured editing action on selected text.
void Function(SelectionActionEvent)? onSelectionAction;