onDecorationInteraction property
Callback invoked when the user interacts with an existing decoration (e.g. taps a highlight).
Implementation
final ValueChanged<DecorationInteractionEvent>? onDecorationInteraction;
Callback invoked when the user interacts with an existing decoration (e.g. taps a highlight).
final ValueChanged<DecorationInteractionEvent>? onDecorationInteraction;