onSelectionAction property
Callback invoked when the user taps a configured editing action on selected text.
Implementation
final ValueChanged<SelectionActionEvent>? onSelectionAction;
Callback invoked when the user taps a configured editing action on selected text.
final ValueChanged<SelectionActionEvent>? onSelectionAction;