onTextSelected property
Callback invoked when the user selects text in the reader.
Implementation
final ValueChanged<TextSelectionEvent>? onTextSelected;
Callback invoked when the user selects text in the reader.
final ValueChanged<TextSelectionEvent>? onTextSelected;