shouldShowControls property
Notifier that tells client whether it should show controls, based on user-interaction with the native viewer.
Implementation
final ValueNotifier<bool>? shouldShowControls;
Notifier that tells client whether it should show controls, based on user-interaction with the native viewer.
final ValueNotifier<bool>? shouldShowControls;