ReadiumReaderWidget class

Inheritance

Constructors

ReadiumReaderWidget({required Publication publication, Widget loadingWidget = const Center(child: CircularProgressIndicator()), Locator? initialLocator, ValueNotifier<bool>? shouldShowControls, dynamic onExternalLinkActivated(String)?, String goBackwardSemanticLabel = 'Go Backward', String goForwardSemanticLabel = 'Go Forward', String toggleShowControlsSemanticLabel = 'Toggle show controls', bool verticalScroll = false, void onTextSelected(TextSelectionEvent)?, void onSelectionAction(SelectionActionEvent)?, void onDecorationInteraction(DecorationInteractionEvent)?, List<SelectionAction>? selectionActions, Set<DefaultSelectionAction>? allowedDefaultActions, Key? key})
const

Properties

allowedDefaultActions Set<DefaultSelectionAction>?
final
goBackwardSemanticLabel String
final
goForwardSemanticLabel String
final
hashCode int
The hash code for this object.
no setterinherited
initialLocator Locator?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget Widget
final
onDecorationInteraction → void Function(DecorationInteractionEvent)?
final
onExternalLinkActivated → dynamic Function(String)?
final
onSelectionAction → void Function(SelectionActionEvent)?
final
onTextSelected → void Function(TextSelectionEvent)?
final
publication Publication
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionActions List<SelectionAction>?
final
shouldShowControls ValueNotifier<bool>?
final
toggleShowControlsSemanticLabel String
final
verticalScroll bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ReadiumReaderWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited