flutter_readium
library
Classes
Accessibility
Accessibility Object
AccessibilityAccessModeSufficient
Represents a sufficient access mode, which can be a single mode or a list of modes.
AccessibilityCertification
Acquisition
OPDS Acquisition Object.
AcquisitionLink
AdditionalProperties
AltIdentifier
Alternate Identifiers
Announcement
Announcement object
See: https://github.com/NYPL-Simplified/Simplified/wiki/Authentication-For-OPDS-Extensions#sitewide-announcements
Article
Article
AudioPreferences
Availability
Indicated the availability of a given resource.
BelongsTo
BelongsTo Object for the Metadata object.
Chapter
Chapter collection object.
Charset
Charsets
Collection
Collection
Contributor
Contributor
Copies
Library-specific feature that contains information about the copies that a library has acquired.
DecorationInteractionEvent
Fired when the user interacts with an existing decoration (e.g. taps a highlight).
DomRange
This construct enables a serializable representation of a DOM Range.
Drm
EncryptedProperties
Encryption
Indicates that a resource is encrypted/obfuscated and provides relevant information for decryption.
Episode
Episode collection object.
EPUBPreferences
Facet
FeatureFlags
FeatureFlags class
See: https://github.com/NYPL-Simplified/Simplified/wiki/Authentication-For-OPDS-Extensions#feature-flags
Feed
FlutterReadium
Unified API for interacting with the Readium toolkits across platforms, providing methods for loading publications,
navigating content, controlling audio and TTS playback, and receiving updates on reader status and locator changes.
FlutterReadiumPlatform
The interface that implementations of FlutterReadium must implement.
Group
GuidedNavigationDescription
Alternative description for a guided navigation object, using one or more
media references.
GuidedNavigationDocument
A Readium Guided Navigation Document, describing a structured sequence of
media-aligned navigation steps for a publication.
GuidedNavigationObject
A single step in a guided navigation sequence.
GuidedNavigationText
Text associated with a guided navigation object or description.
GuidedNavigationTextObject
A guided navigation text represented as a structured object with optional
SSML markup and BCP 47 language tag.
GuidedNavigationTextString
A guided navigation text represented as a plain string.
Holds
Library-specific features when a specific book is unavailable but provides a hold list.
Href
Represents an HREF, optionally relative to another one.
TODO: Currently it does NOT resolve ""../" notations.
ImageTapEvent
Fired when the user taps an image inside an EPUB.
InputData
InputField
Issue
Issue collection object.
JSONable
An interface for classes that can be serialized to JSON.
Subclasses must implement toJson and a static fromJson method.
As well as a JsonConverter.
Link
Link to a resource, either relative to a Publication or external (remote).
LocalizedString
A potentially localized (multilingual) string.
Locations
One or more alternative expressions of the location.
https://github.com/readium/architecture/tree/master/models/locators#the-location-object
https://github.com/readium/architecture/blob/master/models/locators/extensions/html.md
Locator
Provides a precise location in a publication in a format that can be stored and shared.
LocatorCollection
Represents a sequential list of Locator objects.
LocatorCollectionMetadata
Holds the metadata of a LocatorCollection .
LocatorText
Textual context of the locator.
LoginInputField
MediaType
Represents a document format, identified by a unique RFC 6838 media type.
Metadata
https://readium.org/webpub-manifest/schema/metadata.schema.json
MetadataContains
MetdataMediaOverlay
OdlCheckouts
Checkout availability counters in an ODL 1.0 License Info Document.
OdlLicenseInfoDocument
An ODL 1.0 License Info Document — the JSON document returned at the
license status URL embedded in an OPDS 2.0 feed.
OdlLicenseMetadata
Properties of an ODL 1.0 license, embedded in an OPDS 2.0 link's properties
object under the key license.
OdlLoan
An active loan record embedded in an ODL 1.0 License Info Document.
OdlProtection
DRM protection constraints embedded in an ODL 1.0 license.
OdlTerms
Checkout terms embedded in an ODL 1.0 license.
OpdsAuthentication
OPDS Authentication Object plus NYPL additions.
https://drafts.opds.io/schema/authentication.schema.json
OpdsAuthenticationFlow
OpdsAuthenticationLabels
OpdsMetadata
OpdsPublication
PDFPreferences
Periodical
Periodical collection.
Point
A serializable representation of a boundary point in a DOM Range.
PositionsList
Readium's positions list: see https://github.com/readium/architecture/tree/master/models/locators/positions
Presentation
The Presentation Hints extension defines a number of hints for User Agents about the way content
should be presented to the user.
Price
The price of a publication in an OPDS link.
Profile
OPDS Profile Document
https://drafts.opds.io/schema/opds-profile.schema.json
ProfileHolds
ProfileLoans
Properties
Set of properties associated with a Link .
Publication
Holds the metadata of a Readium publication, as described in the Readium Web Publication Manifest.
PublicationCollection
Core Collection Model
PublicationFormat
Format of the Publication file.
PublicKeyData
If your OPDS server needs to receive cryptographically signed messages (e.g. to set up shared secrets with other servers),
you can publish your public key in the authentication document.
QueryParameter
ReaderDecoration
ReaderDecorationStyle
ReaderTTSVoice
ReaderTTSVoiceUtils
Utility functions for working with TTS voices, including loading and matching against the Readium Speech voice data.
ReadiumLog
Plugin-wide logger backed by package:logging.
ReadiumReaderWidget
ReadiumReaderWidgetInterface
ReadiumResourceImageProvider
An ImageProvider that lazily resolves an EPUB image resource to a URL
via the Readium platform bridge (FlutterReadiumPlatform.getResourceUrl )
and loads it from there.
ReadiumSpeechLanguage
Represents a speech language with its associated TTS voices from the Readium Speech repository.
See: https://github.com/readium/speech
ReadiumSpeechVoice
Represents a TTS voice from the Readium Speech repository, with properties that can be used to match against available platform voices.
See: https://github.com/readium/speech
ReadiumTimebasedState
RuntimePlatform
Season
Season collection object.
SelectionAction
Defines a native context menu item shown when text is selected.
SelectionActionEvent
Fired when the user taps a configured editing action on selected text.
Series
Series collection.
StoryArc
Story Arc collection object.
Subject
Subject of a Publication .
TaggedReadiumLog
A tagged variant of ReadiumLog that routes logs through a child logger
named flutter_readium.<tag>. The tag appears in the loggerName field of
LogRecord, making it easy to identify the source of a log message.
TDM
Text and data mining
TextSearchResult
Represents a single text search result within a publication.
Contains a Locator to the location of the search result, an optional chapter title, and optional page numbers.
This class was created to provide a simpler structure rather than sending full LocatorCollection over the bridge.
TextSelectionEvent
Fired when the user selects text in the reader.
TimeFragment
Translation
TTSPreferences
UriTemplate
A lightweight implementation of URI Template (RFC 6570).
Volume
WebColor
Web color scheme.
See: https://github.com/NYPL-Simplified/Simplified/wiki/Authentication-For-OPDS-Extensions#web-color-scheme