DecorationInteractionEvent class
Fired when the user interacts with an existing decoration (e.g. taps a highlight).
- Implemented types
Constructors
- DecorationInteractionEvent({required String decorationId, required String group, required DecorationInteractionType type, Locator? locator})
-
const
-
DecorationInteractionEvent.fromJson(Map<
String, dynamic> map) -
factory
Properties
- decorationId → String
-
The ID of the decoration that was interacted with.
final
- group → String
-
The decoration group this decoration belongs to.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locator → Locator?
-
The locator of the decoration, if available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DecorationInteractionType
-
The type of interaction (tap or long press).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes the object to its JSON representation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited