EPUBPreferences class
Implemented types
Annotations
Constructors
EPUBPreferences ({Color ? backgroundColor , EpubColumnCount ? columnCount , String ? fontFamily , double ? fontSize , double ? fontWeight , bool ? hyphens , EpubImageFilter ? imageFilter , String ? language , double ? letterSpacing , bool ? ligatures , double ? lineHeight , double ? pageMargins , double ? paragraphIndent , double ? paragraphSpacing , bool ? publisherStyles , EpubReadingProgression ? readingProgression , bool ? scroll , String ? spread , TextAlign ? textAlign , Color ? textColor , bool ? textNormalization , double ? typeScale , bool ? verticalText , double ? wordSpacing , bool blackAndWhiteComicMode = false , bool disableSynchronization = false , int ? firstElementTopMargin , bool preventMOColumnBreaks = true })
const
EPUBPreferences.fromJson (Map <String , dynamic > json )
factory
Properties
backgroundColor
→ Color ?
Default page background color.
final
blackAndWhiteComicMode
→ bool
Black and white mode for Nota Comic Books.
When enabled, this mode applies a black and white filter to the comic book pages.
Note: ImageFilter is not supported when this mode is enabled.
final
columnCount
→ EpubColumnCount ?
Number of columns to display in reflowable content.
final
disableSynchronization
→ bool
Seeds the initial narration-sync state for TTS / SyncAudio navigators.
When true, decorations are applied but the EPUB navigator will not scroll
into view or switch chapter/file to follow narration.
final
firstElementTopMargin
→ int ?
Margin applied to the top of the first element in the content.
This is used to create space for UI elements like a toolbar without overlapping the content.
final
fontFamily
→ String ?
Font family for text content.
final
fontSize
→ double ?
Font-size scale relative to the publisher default (1.0 = 100%, 1.5 = 150%).
Forwarded to Readium unchanged on every platform.
final
fontWeight
→ double ?
Font weight for text content.
final
hashCode
→ int
The hash code for this object.
no setter inherited
hyphens
→ bool ?
Hyphenation for text content.
final
imageFilter
→ EpubImageFilter ?
Image filter to apply to images in the content. Note blackAndWhiteComicMode takes precedence over this setting for Nota comic books.
final
language
→ String ?
Language for the content, specified as a BCP 47 language tag (e.g., "en", "fr", "zh-CN").
final
letterSpacing
→ double ?
Letter spacing for text content.
final
ligatures
→ bool ?
Ligatures for text content.
final
lineHeight
→ double ?
Line height for text content.
final
pageMargins
→ double ?
Page margins for the content.
final
paragraphIndent
→ double ?
Text indent for paragraphs.
final
paragraphSpacing
→ double ?
Paragraph spacing for the content.
final
preventMOColumnBreaks
→ bool
When true (default), prevents paragraph elements from splitting across CSS columns during
media-overlay playback. This ensures audio and visible text stay in sync when a paragraph
would otherwise straddle a column boundary. Has no effect outside of media-overlay mode.
final
props
→ List <Object ? >
The list of properties that will be used to determine whether
two instances are equal.
no setter
publisherStyles
→ bool ?
Indicates whether the original publisher styles should be observed. Many settings require this to be off.
final
readingProgression
→ EpubReadingProgression ?
Direction of the reading progression across resources
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
scroll
→ bool ?
Vertical scroll for reflowable content. Default is false, meaning horizontal pagination.
final
spread
→ String ?
Indicates if the fixed-layout publication should be rendered with a synthetic spread (dual-page).
final
stringify
→ bool ?
If set to true, the toString method will be overridden to output
this instance's props.
no setter inherited
textAlign
→ TextAlign ?
Text alignment
final
textColor
→ Color ?
Text color.
final
textNormalization
→ bool ?
Normalize text styles to increase accessibility
final
typeScale
→ double ?
Scale applied to all element font sizes.
final
verticalText
→ bool ?
Indicates whether the text should be laid out vertically. This is used
for example with CJK languages. This setting is automatically derived from the language if
no preference is given.
final
wordSpacing
→ double ?
Space between words.
final
Methods
copyWith ({Color ? backgroundColor , EpubColumnCount ? columnCount , String ? fontFamily , double ? fontSize , double ? fontWeight , bool ? hyphens , EpubImageFilter ? imageFilter , String ? language , double ? letterSpacing , bool ? ligatures , double ? lineHeight , double ? pageMargins , double ? paragraphIndent , double ? paragraphSpacing , bool ? publisherStyles , EpubReadingProgression ? readingProgression , bool ? scroll , String ? spread , TextAlign ? textAlign , Color ? textColor , bool ? textNormalization , double ? typeScale , bool ? verticalText , double ? wordSpacing , bool ? blackAndWhiteComicMode , bool ? disableSynchronization , int ? firstElementTopMargin , bool ? preventMOColumnBreaks })
→ EPUBPreferences
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson ()
→ Map <String , dynamic >
Serializes the object to its JSON representation.
override
toString ()
→ String
A string representation of this object.
inherited