Metadata class
https://readium.org/webpub-manifest/schema/metadata.schema.json
@param readingProgression WARNING: This contains the reading progression as declared in the publication, so it might be ReadingProgression.auto. To lay out the content, use effectiveReadingProgression to get the calculated reading progression from the declared direction and the language. @param additionalProperties Additional metadata for extensions, as a JSON dictionary.
- Inheritance
-
- Object
- AdditionalProperties
- Metadata
- Implemented types
- Available extensions
- Annotations
Constructors
-
Metadata({required LocalizedString localizedTitle, String? identifier, String? rdfType, List<
String> ? conformsTo, LocalizedString? localizedSubtitle, Accessibility? accessibility, DateTime? modified, DateTime? published, List<String> languages = const [], LocalizedString? localizedSortAs, List<Subject> subjects = const [], List<Contributor> authors = const [], List<Contributor> contributors = const [], List<Contributor> translators = const [], List<Contributor> editors = const [], List<Contributor> artists = const [], List<Contributor> illustrators = const [], List<Contributor> letterers = const [], List<Contributor> pencilers = const [], List<Contributor> colorists = const [], List<Contributor> inkers = const [], List<Contributor> narrators = const [], List<Contributor> publishers = const [], List<Contributor> imprints = const [], String? description, double? duration, int? numberOfPages, String? layout, BelongsTo belongsTo = const BelongsTo(), TDM? tdm, ReadingProgression readingProgression = ReadingProgression.auto, Presentation? rendition, List<AltIdentifier> ? altIdentifiers, MetadataContains contains = const MetadataContains(), Map<String, dynamic> additionalProperties = const {}}) -
const
Properties
- accessibility → Accessibility?
-
final
-
additionalProperties
→ Map<
String, dynamic> -
finalinherited
-
altIdentifiers
→ List<
AltIdentifier> ? -
final
-
artists
→ List<
Contributor> -
final
-
final
- belongsTo → BelongsTo
-
final
-
colorists
→ List<
Contributor> -
final
-
conformsTo
→ List<
String> ? -
final
- contains → MetadataContains
-
final
-
contributors
→ List<
Contributor> -
final
- description → String?
-
final
- duration → double?
-
final
-
editors
→ List<
Contributor> -
final
- effectiveReadingProgression → ReadingProgression
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String?
-
An URI used as the unique identifier for this Publication.
final
-
illustrators
→ List<
Contributor> -
final
-
imprints
→ List<
Contributor> -
final
-
inkers
→ List<
Contributor> -
final
-
languages
→ List<
String> -
Languages used in the publication.
final
- layout → String?
-
final
-
letterers
→ List<
Contributor> -
final
- localizedSortAs → LocalizedString?
-
Alternative title to be used for sorting the publication in the library.
final
- localizedSubtitle → LocalizedString?
-
final
- localizedTitle → LocalizedString
-
final
- mediaOverlay → MetdataMediaOverlay?
-
Available on Metadata, provided by the EpubMetadataExtension extension
no setter - modified → DateTime?
-
final
-
narrators
→ List<
Contributor> -
final
- numberOfPages → int?
-
Number of pages in the publication, if available.
final
-
pencilers
→ List<
Contributor> -
final
- presentation → Presentation
-
Available on Metadata, provided by the PresentionMetadataExtension extension
no setter -
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- published → DateTime?
-
final
-
publishers
→ List<
Contributor> -
final
- rdfType → String?
-
final
- readingProgression → ReadingProgression
-
Direction of the Publication reading progression.
final
- rendition → Presentation?
-
Information about the contents rendition.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortAs → String?
-
Returns the default translation string for the localizedSortAs.
no setter
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
subjects
→ List<
Subject> -
Themes/subjects of the publication.
final
- tdm → TDM?
-
final
- title → String
-
Returns the default translation string for the localizedTitle.
no setter
-
translators
→ List<
Contributor> -
final
Methods
-
copyWith(
{String? identifier, String? rdfType, LocalizedString? localizedTitle, LocalizedString? localizedSubtitle, DateTime? modified, DateTime? published, List< String> ? languages, LocalizedString? localizedSortAs, List<Subject> ? subjects, List<Contributor> ? authors, List<Contributor> ? publishers, List<Contributor> ? contributors, List<Contributor> ? translators, List<Contributor> ? editors, List<Contributor> ? artists, List<Contributor> ? illustrators, List<Contributor> ? letterers, List<Contributor> ? pencilers, List<Contributor> ? colorists, List<Contributor> ? inkers, List<Contributor> ? narrators, List<Contributor> ? imprints, String? description, double? duration, int? numberOfPages, BelongsTo? belongsTo, TDM? tdm, ReadingProgression? readingProgression, Presentation? rendition, List<AltIdentifier> ? altIdentifiers, MetadataContains? contains, Map<String, dynamic> ? additionalProperties}) → Metadata -
getAdditionalDateTime(
String key) → DateTime? -
Helper to get a DateTime from an additional property value.
inherited
-
getAdditionalEnum<
T extends Enum> (String key, List< T> enumValues) → T? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
safeGetAdditionalValue<
T> (String key) → T? -
Safely get an additional property value of type
T.inherited -
toJson(
) → Map< String, dynamic> -
Serializes a Metadata to its RWPM JSON representation.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → dynamic -
Syntactic sugar to access the additionalProperties values by subscripting directly.
obj["layout"] == obj.additionalProperties["layout"]inherited