PresentationSpread enum
Indicates the condition to be met for the linked resource to be rendered within a synthetic spread.
Values
- auto → const PresentationSpread
-
Specifies the Reading System can determine when to render a synthetic spread for the readingOrder item.
- both → const PresentationSpread
-
Specifies the Reading System should render a synthetic spread for the readingOrder item in both portrait and landscape orientations.
- none → const PresentationSpread
-
Specifies the Reading System should not render a synthetic spread for the readingOrder item.
- landscape → const PresentationSpread
-
Specifies the Reading System should render a synthetic spread for the readingOrder item only when in landscape orientation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String? value) → PresentationSpread?
Constants
-
values
→ const List<
PresentationSpread> - A constant List of the values in this enum, in order of their declaration.